datastructuretools.TypedCounter
===============================

.. abjad-lineage:: abjad.tools.datastructuretools.TypedCounter.TypedCounter

.. autoclass:: abjad.tools.datastructuretools.TypedCounter.TypedCounter

.. only:: html

   Attribute summary
   -----------------

   .. autosummary::

      ~abjad.tools.datastructuretools.TypedCounter.TypedCounter.clear
      ~abjad.tools.datastructuretools.TypedCounter.TypedCounter.copy
      ~abjad.tools.datastructuretools.TypedCounter.TypedCounter.elements
      ~abjad.tools.datastructuretools.TypedCounter.TypedCounter.item_class
      ~abjad.tools.datastructuretools.TypedCounter.TypedCounter.items
      ~abjad.tools.datastructuretools.TypedCounter.TypedCounter.keys
      ~abjad.tools.datastructuretools.TypedCounter.TypedCounter.most_common
      ~abjad.tools.datastructuretools.TypedCounter.TypedCounter.subtract
      ~abjad.tools.datastructuretools.TypedCounter.TypedCounter.update
      ~abjad.tools.datastructuretools.TypedCounter.TypedCounter.values
      ~abjad.tools.datastructuretools.TypedCounter.TypedCounter.viewitems
      ~abjad.tools.datastructuretools.TypedCounter.TypedCounter.viewkeys
      ~abjad.tools.datastructuretools.TypedCounter.TypedCounter.viewvalues
      ~abjad.tools.datastructuretools.TypedCounter.TypedCounter.__add__
      ~abjad.tools.datastructuretools.TypedCounter.TypedCounter.__and__
      ~abjad.tools.datastructuretools.TypedCounter.TypedCounter.__contains__
      ~abjad.tools.datastructuretools.TypedCounter.TypedCounter.__delitem__
      ~abjad.tools.datastructuretools.TypedCounter.TypedCounter.__eq__
      ~abjad.tools.datastructuretools.TypedCounter.TypedCounter.__format__
      ~abjad.tools.datastructuretools.TypedCounter.TypedCounter.__getitem__
      ~abjad.tools.datastructuretools.TypedCounter.TypedCounter.__hash__
      ~abjad.tools.datastructuretools.TypedCounter.TypedCounter.__iter__
      ~abjad.tools.datastructuretools.TypedCounter.TypedCounter.__len__
      ~abjad.tools.datastructuretools.TypedCounter.TypedCounter.__missing__
      ~abjad.tools.datastructuretools.TypedCounter.TypedCounter.__ne__
      ~abjad.tools.datastructuretools.TypedCounter.TypedCounter.__or__
      ~abjad.tools.datastructuretools.TypedCounter.TypedCounter.__repr__
      ~abjad.tools.datastructuretools.TypedCounter.TypedCounter.__setitem__
      ~abjad.tools.datastructuretools.TypedCounter.TypedCounter.__sub__

Bases
-----

- :py:class:`datastructuretools.TypedCollection <abjad.tools.datastructuretools.TypedCollection.TypedCollection>`

- :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject>`

- :py:class:`abctools.AbjadObject.AbstractBase <abjad.tools.abctools.AbjadObject.AbstractBase>`

- :py:class:`__builtin__.object <object>`

Read-only properties
--------------------

.. autoattribute:: abjad.tools.datastructuretools.TypedCounter.TypedCounter.item_class
   :noindex:

Methods
-------

.. automethod:: abjad.tools.datastructuretools.TypedCounter.TypedCounter.clear
   :noindex:

.. automethod:: abjad.tools.datastructuretools.TypedCounter.TypedCounter.copy
   :noindex:

.. automethod:: abjad.tools.datastructuretools.TypedCounter.TypedCounter.elements
   :noindex:

.. automethod:: abjad.tools.datastructuretools.TypedCounter.TypedCounter.items
   :noindex:

.. automethod:: abjad.tools.datastructuretools.TypedCounter.TypedCounter.keys
   :noindex:

.. automethod:: abjad.tools.datastructuretools.TypedCounter.TypedCounter.most_common
   :noindex:

.. automethod:: abjad.tools.datastructuretools.TypedCounter.TypedCounter.subtract
   :noindex:

.. automethod:: abjad.tools.datastructuretools.TypedCounter.TypedCounter.update
   :noindex:

.. automethod:: abjad.tools.datastructuretools.TypedCounter.TypedCounter.values
   :noindex:

.. automethod:: abjad.tools.datastructuretools.TypedCounter.TypedCounter.viewitems
   :noindex:

.. automethod:: abjad.tools.datastructuretools.TypedCounter.TypedCounter.viewkeys
   :noindex:

.. automethod:: abjad.tools.datastructuretools.TypedCounter.TypedCounter.viewvalues
   :noindex:

Special methods
---------------

.. automethod:: abjad.tools.datastructuretools.TypedCounter.TypedCounter.__add__
   :noindex:

.. automethod:: abjad.tools.datastructuretools.TypedCounter.TypedCounter.__and__
   :noindex:

.. automethod:: abjad.tools.datastructuretools.TypedCounter.TypedCounter.__contains__
   :noindex:

.. automethod:: abjad.tools.datastructuretools.TypedCounter.TypedCounter.__delitem__
   :noindex:

.. automethod:: abjad.tools.datastructuretools.TypedCounter.TypedCounter.__eq__
   :noindex:

.. automethod:: abjad.tools.datastructuretools.TypedCounter.TypedCounter.__format__
   :noindex:

.. automethod:: abjad.tools.datastructuretools.TypedCounter.TypedCounter.__getitem__
   :noindex:

.. automethod:: abjad.tools.datastructuretools.TypedCounter.TypedCounter.__hash__
   :noindex:

.. automethod:: abjad.tools.datastructuretools.TypedCounter.TypedCounter.__iter__
   :noindex:

.. automethod:: abjad.tools.datastructuretools.TypedCounter.TypedCounter.__len__
   :noindex:

.. automethod:: abjad.tools.datastructuretools.TypedCounter.TypedCounter.__missing__
   :noindex:

.. automethod:: abjad.tools.datastructuretools.TypedCounter.TypedCounter.__ne__
   :noindex:

.. automethod:: abjad.tools.datastructuretools.TypedCounter.TypedCounter.__or__
   :noindex:

.. automethod:: abjad.tools.datastructuretools.TypedCounter.TypedCounter.__repr__
   :noindex:

.. automethod:: abjad.tools.datastructuretools.TypedCounter.TypedCounter.__setitem__
   :noindex:

.. automethod:: abjad.tools.datastructuretools.TypedCounter.TypedCounter.__sub__
   :noindex:
